@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 
-###################################################################
+################################################################### 
 ## Primary Author:  Rohit Singh rsingh@alum.mit.edu
 ## Co-Authors: Ashwin Narayan, Brian Hie {ashwinn,brianhie}@mit.edu
 ## License: MIT
@@ -10,7 +10,6 @@
 
 import pandas as pd
 import numpy as np
-import numba
 import scipy, sklearn
 import os, sys, string, fileinput, glob, re, math, itertools, functools, copy, logging, warnings
 import sklearn.decomposition, sklearn.preprocessing
